'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const validationHtml = require('@aurelia/validation-html');
const runtimeHtml = require('@aurelia/runtime-html');
const kernel = require('@aurelia/kernel');
const banner = require('@material/banner');
require('@material/web/icon/icon.js');
require('@material/web/button/elevated-button.js');
require('@material/web/button/filled-button.js');
require('@material/web/button/outlined-button.js');
require('@material/web/button/text-button.js');
require('@material/web/button/filled-tonal-button.js');
const chips = require('@material/chips');
const circularProgress = require('@material/circular-progress');
require('devextreme/dist/css/dx.material.purple.dark.compact.css');
const dialog = require('@material/dialog');
const drawer = require('@material/drawer');
const formField = require('@material/form-field');
const radio = require('@material/radio');
require('@material/web/switch/switch');
const topAppBar = require('@material/top-app-bar');

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */


function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __param(paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
}

function __metadata(metadataKey, metadataValue) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
}

let Align = class Align {
    element;
    value;
    constructor(element){
        this.element = element;
    }
    afterBind() {
        this.element.style.textAlign = this.value ?? '';
    }
    /* Example of change detection */ valueChanged() {
        this.afterBind();
    }
};
__decorate([
    runtimeHtml.bindable(),
    __metadata("design:type", String)
], Align.prototype, "value", void 0);
Align = __decorate([
    runtimeHtml.customAttribute({
        name: 'align'
    }),
    __param(0, runtimeHtml.INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], Align);

let FullHeight = class FullHeight {
    element;
    constructor(element){
        this.element = element;
        this.element.style.height = '100%';
    }
};
FullHeight = __decorate([
    runtimeHtml.customAttribute({
        name: 'full-height'
    }),
    __param(0, runtimeHtml.INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], FullHeight);

let FullWidth = class FullWidth {
    element;
    constructor(element){
        this.element = element;
        this.element.style.width = '100%';
    }
};
FullWidth = __decorate([
    runtimeHtml.customAttribute({
        name: 'full-width'
    }),
    __param(0, runtimeHtml.INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], FullWidth);

let Link = class Link {
    htmlElement;
    platform;
    value = '';
    constructor(htmlElement, platform){
        this.htmlElement = htmlElement;
        this.platform = platform;
        htmlElement.addEventListener('mousedown', this.clickEvent);
    }
    clickEvent = ()=>{
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        //@ts-ignore
        this.platform.window.open(this.value, '_blank');
    };
    detaching() {
        this.htmlElement.removeEventListener('mousedown', this.clickEvent);
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], Link.prototype, "value", void 0);
Link = __decorate([
    runtimeHtml.customAttribute({
        name: 'link',
        noMultiBindings: true
    }),
    __param(0, runtimeHtml.INode),
    __param(1, kernel.IPlatform),
    __metadata("design:paramtypes", [
        HTMLElement,
        Object
    ])
], Link);

let Ripple = class Ripple {
    htmlElement;
    platform;
    speed = 1;
    color = '';
    rippleContainer;
    ripple;
    constructor(htmlElement, platform){
        this.htmlElement = htmlElement;
        this.platform = platform;
        htmlElement?.addEventListener('mousedown', this.rippleEvent);
    }
    rippleEvent = (event)=>{
        if (!this.htmlElement) return;
        const offsetInfo = this.htmlElement.getBoundingClientRect();
        this.createContainer(offsetInfo);
        this.createRipple(offsetInfo, event);
    };
    createRipple = (offsetInfo, event)=>{
        const maxLength = offsetInfo.width > offsetInfo.height ? offsetInfo.width : offsetInfo.height;
        const circleD = maxLength * 2;
        this.ripple = document.createElement('div');
        this.ripple.style.position = 'absolute';
        this.ripple.style.pointerEvents = 'none';
        this.ripple.style.width = `${circleD}px`;
        this.ripple.style.height = `${circleD}px`;
        this.ripple.style.borderRadius = '500px';
        this.ripple.style.left = `${event.pageX - offsetInfo.left - circleD / 2}px`;
        this.ripple.style.top = `${event.pageY - offsetInfo.top - circleD / 2}px`;
        this.ripple.style.animationDuration = `${this.speed}s`;
        this.ripple.style.background = this.color || 'rgba(var(--san-juan-900-rgb), var(--alpha-sm))';
        this.ripple.className = 'ripple';
        this.rippleContainer?.appendChild(this.ripple);
        this.ripple.addEventListener('animationend', this.removeContainer, false);
    };
    createContainer(offsetInfo) {
        if (!this.htmlElement) return;
        const ripplerContainer = this.htmlElement.querySelector('.ripple-container');
        if (ripplerContainer) {
            ripplerContainer.remove();
        }
        this.rippleContainer = document.createElement('div');
        this.rippleContainer.style.position = 'fixed';
        this.rippleContainer.style.zIndex = '99';
        this.rippleContainer.style.width = `${offsetInfo.width}px`;
        this.rippleContainer.style.left = `${offsetInfo.left}px`;
        this.rippleContainer.style.top = `${offsetInfo.top}px`;
        this.rippleContainer.style.height = `${offsetInfo.height}px`;
        this.rippleContainer.className = 'ripple-container';
        this.rippleContainer.style.pointerEvents = 'none';
        this.rippleContainer.style.overflow = 'hidden';
        this.htmlElement.appendChild(this.rippleContainer);
    }
    removeContainer = ()=>{
        this.rippleContainer?.remove();
        this.ripple?.removeEventListener('animationend', this.removeContainer);
    };
    detaching() {
        if (!this.htmlElement) return;
        this.htmlElement.removeEventListener('mousedown', this.rippleEvent);
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], Ripple.prototype, "speed", void 0);
__decorate([
    runtimeHtml.bindable({
        primary: true
    }),
    __metadata("design:type", Object)
], Ripple.prototype, "color", void 0);
Ripple = __decorate([
    runtimeHtml.customAttribute({
        name: 'ripple'
    }),
    __param(1, kernel.IPlatform),
    __metadata("design:paramtypes", [
        HTMLElement,
        Object
    ])
], Ripple);

let Underline = class Underline {
    element;
    constructor(element){
        this.element = element;
        this.element.style.textDecoration = 'underline';
    }
};
Underline = __decorate([
    runtimeHtml.customAttribute({
        name: 'underline'
    }),
    __param(0, runtimeHtml.INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], Underline);

let Elevation = class Elevation {
    element;
    value;
    constructor(element){
        this.element = element;
        this.element.style.boxShadow = '0 8px 12px rgba(0, 0, 0, 0.1), 0 2px 6px rgba(0, 0, 0, 0.08)';
        //this.element.style.border = "1px solid black";
        this.element.style.borderRadius = '5px';
    }
};
__decorate([
    runtimeHtml.bindable(),
    __metadata("design:type", String)
], Elevation.prototype, "value", void 0);
Elevation = __decorate([
    runtimeHtml.customAttribute({
        name: 'elevation'
    }),
    __param(0, runtimeHtml.INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], Elevation);

const attributes = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get Align () { return Align; },
    get Elevation () { return Elevation; },
    get FullHeight () { return FullHeight; },
    get FullWidth () { return FullWidth; },
    get Link () { return Link; },
    get Ripple () { return Ripple; },
    get Underline () { return Underline; }
}, Symbol.toStringTag, { value: 'Module' }));

const IBetsyWebComponentsConfiguration = kernel.DI.createInterface('IBetsyWebComponentsConfiguration');

const mooAccordion = '';

const template$q = "<div class=\"accordion-item ${extraAccordionClasses}\" ref=\"accordionItemEl\" ...$attrs>\n    <div class=\"accordion-header\" tabindex=\"0\" ref=\"accordionHeaderEl\">\n        <span>${header}</span>\n    </div>\n    <div class=\"accordion-content\">\n        <au-slot></au-slot>\n    </div>\n</div>\n";

let MooAccordion = class MooAccordion {
    header;
    accordionItemEl;
    accordionHeaderEl;
    closeAllOtherAccordions(element) {
        const accordionHeaders = document.querySelectorAll('.accordion-header');
        accordionHeaders.forEach((header)=>{
            if (header !== element) {
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-ignore
                header.parentElement.classList.remove('accordion-expanded');
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-expect-error
                header.nextElementSibling.style.maxHeight = 0;
            }
        });
    }
    attached() {
        this.accordionHeaderEl.addEventListener('click', ()=>{
            const content = this.accordionHeaderEl.nextElementSibling;
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            const isOpen = this.accordionHeaderEl.parentElement.classList.contains('accordion-expanded');
            this.closeAllOtherAccordions(this.accordionHeaderEl);
            if (isOpen) {
                content.style.maxHeight = '0';
            } else {
                content.style.maxHeight = content.scrollHeight + 50 + 'px';
            }
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            this.accordionHeaderEl.parentElement.classList.toggle('accordion-expanded');
        });
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooAccordion.prototype, "header", void 0);
MooAccordion = __decorate([
    runtimeHtml.customElement({
        name: 'moo-accordion',
        template: template$q,
        containerless: true,
        capture: true
    })
], MooAccordion);

const mooBanner = '';

const template$p = "<div class=\"mdc-banner\" role=\"banner\" ref=\"bannerEl\">\n    <div class=\"mdc-banner__content\"\n         role=\"alertdialog\"\n         aria-live=\"assertive\">\n        <div class=\"mdc-banner__graphic-text-wrapper\">\n            <div class=\"mdc-banner__text\">\n                <au-slot></au-slot>\n            </div>\n        </div>\n        <div class=\"mdc-banner__actions\">\n            <moo-button type=\"button\" class=\"mdc-banner__secondary-action\" if.bind=\"secondaryAction\">\n                <div class=\"mdc-button__ripple\"></div>\n                <div class=\"mdc-button__label\">\n                    ${secondaryAction}\n                </div>\n            </moo-button>\n            <moo-button type=\"button\" class=\"mdc-banner__primary-action\" if.bind=\"primaryAction\">\n                <div class=\"mdc-button__ripple\"></div>\n                <div class=\"mdc-button__label\">\n                    ${primaryAction}\n                </div>\n            </moo-button>\n        </div>\n    </div>\n</div>\n";

let MooBanner = class MooBanner {
    primaryAction;
    secondaryAction;
    open;
    bannerEl;
    banner;
    attached() {
        this.banner = new banner.MDCBanner(this.bannerEl);
        if (this.open) {
            this.banner.open();
        }
    }
    openChanged() {
        if (this.open) {
            this.banner.open();
        } else {
            this.banner.close(banner.CloseReason.PRIMARY);
        }
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooBanner.prototype, "primaryAction", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooBanner.prototype, "secondaryAction", void 0);
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooBanner.prototype, "open", void 0);
MooBanner = __decorate([
    runtimeHtml.customElement({
        name: 'moo-banner',
        template: template$p,
        containerless: true,
        capture: true
    })
], MooBanner);

const template$o = "<md-filled-button\n    ...$attrs\n    if.bind=\"variant === 'filled'\"\n    disabled.bind=\"disabled\"\n    data-mdc-dialog-action.bind=\"dataMdcDialogAction\"\n>\n    <au-slot></au-slot>\n</md-filled-button>\n\n<md-filled-tonal-button\n        ...$attrs\n        if.bind=\"variant === 'filled-tonal'\"\n        disabled.bind=\"disabled\"\n        data-mdc-dialog-action.bind=\"dataMdcDialogAction\"\n>\n    <au-slot></au-slot>\n</md-filled-tonal-button>\n\n<md-outlined-button\n    ...$attrs\n    if.bind=\"variant === 'outlined'\"\n    disabled.bind=\"disabled\"\n    data-mdc-dialog-action.bind=\"dataMdcDialogAction\"\n>\n    <au-slot></au-slot>\n</md-outlined-button>\n\n<md-text-button\n    ...$attrs\n    if.bind=\"variant === 'text'\"\n    disabled.bind=\"disabled\"\n    data-mdc-dialog-action.bind=\"dataMdcDialogAction\"\n>\n    <au-slot></au-slot>\n</md-text-button>\n\n<md-elevated-button\n    ...$attrs\n    if.bind=\"variant === 'elevated'\"\n    disabled.bind=\"disabled\"\n    data-mdc-dialog-action.bind=\"dataMdcDialogAction\"\n>\n    <au-slot></au-slot>\n</md-elevated-button>\n";

let MooButton = class MooButton {
    button;
    label;
    variant = 'filled';
    icon;
    click;
    dataMdcDialogAction;
    disabled = false;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooButton.prototype, "label", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooButton.prototype, "variant", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooButton.prototype, "icon", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Function)
], MooButton.prototype, "click", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooButton.prototype, "dataMdcDialogAction", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooButton.prototype, "disabled", void 0);
MooButton = __decorate([
    runtimeHtml.customElement({
        name: 'moo-button',
        template: template$o,
        containerless: true,
        capture: true
    })
], MooButton);

const mooCard = '';

const template$n = "<div class=\"card\">\n    <au-slot></au-slot>\n</div>\n";

let MooCard = class MooCard {
    outlined;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooCard.prototype, "outlined", void 0);
MooCard = __decorate([
    runtimeHtml.customElement({
        name: 'moo-banner',
        template: template$n,
        containerless: true
    })
], MooCard);

const template$m = "<div class=\"card-content\">\n    <au-slot></au-slot>\n</div>\n";

let MooCardContent = class MooCardContent {
    outlined;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooCardContent.prototype, "outlined", void 0);
MooCardContent = __decorate([
    runtimeHtml.customElement({
        name: 'moo-card-content',
        template: template$m,
        containerless: true
    })
], MooCardContent);

const template$l = "<div class=\"card-footer\">\n    <au-slot></au-slot>\n</div>\n";

let MooCardFooter = class MooCardFooter {
    outlined;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooCardFooter.prototype, "outlined", void 0);
MooCardFooter = __decorate([
    runtimeHtml.customElement({
        name: 'moo-card-footer',
        template: template$l,
        containerless: true
    })
], MooCardFooter);

const template$k = "<div class=\"card-header\">\n    <au-slot></au-slot>\n</div>\n";

let MooCardHeader = class MooCardHeader {
    outlined;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooCardHeader.prototype, "outlined", void 0);
MooCardHeader = __decorate([
    runtimeHtml.customElement({
        name: 'moo-card-header',
        template: template$k,
        containerless: true
    })
], MooCardHeader);

const template$j = "<label ...$attrs class=\"moo-checkbox_align-center\">\n    <md-checkbox touch-target=\"wrapper\" checked.bind=\"checked\" value.bind=\"value\" click.trigger=\"() => handleChange()\"></md-checkbox>\n    <au-slot></au-slot>\n</label>\n";

const mooCheckbox = '';

let MooCheckbox = class MooCheckbox {
    checked;
    changed;
    value;
    handleChange() {
        this.checked = !this.checked;
        if (this.changed) {
            this.changed(this.value, this.checked);
        }
    }
};
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Boolean)
], MooCheckbox.prototype, "checked", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Function)
], MooCheckbox.prototype, "changed", void 0);
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", String)
], MooCheckbox.prototype, "value", void 0);
MooCheckbox = __decorate([
    runtimeHtml.customElement({
        name: 'moo-checkbox',
        template: template$j,
        containerless: true,
        capture: true
    })
], MooCheckbox);

const mooChip = '';

const template$i = "<span class=\"mdc-evolution-chip\" role=\"row\" id=\"c0\">\n      <span class=\"mdc-evolution-chip__cell mdc-evolution-chip__cell--primary\" role=\"gridcell\">\n        <button class=\"mdc-evolution-chip__action mdc-evolution-chip__action--primary\" type=\"button\" tabindex=\"0\">\n          <span class=\"mdc-evolution-chip__ripple mdc-evolution-chip__ripple--primary\"></span>\n          <span class=\"mdc-evolution-chip__text-label\">\n              <au-slot></au-slot>\n          </span>\n        </button>\n      </span>\n    </span>\n";

let MooChip = class MooChip {
};
MooChip = __decorate([
    runtimeHtml.customElement({
        name: 'moo-chip',
        template: template$i,
        containerless: true
    })
], MooChip);

const mooChipSet = '';

const template$h = "<span class=\"mdc-evolution-chip-set\" role=\"grid\" ref=\"chipSetEl\">\n    <span class=\"mdc-evolution-chip-set__chips\" role=\"presentation\">\n        <au-slot></au-slot>\n    </span>\n</span>\n";

let MooChipSet = class MooChipSet {
    chipSetEl;
    size;
    attached() {
        new chips.MDCChipSet(this.chipSetEl);
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Number)
], MooChipSet.prototype, "size", void 0);
MooChipSet = __decorate([
    runtimeHtml.customElement({
        name: 'moo-chip-set',
        template: template$h,
        containerless: true
    })
], MooChipSet);

const mooCircularProgress = '';

const template$g = "<div class=\"mdc-circular-progress\" style=\"width:48px;height:48px;\" role=\"progressbar\" aria-label=\"Example Progress Bar\" aria-valuemin=\"0\" aria-valuemax=\"1\" ref=\"progressEl\">\n    <div class=\"mdc-circular-progress__determinate-container\">\n        <svg class=\"mdc-circular-progress__determinate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n            <circle class=\"mdc-circular-progress__determinate-track\" cx=\"24\" cy=\"24\" r=\"18\" stroke-width=\"4\"/>\n            <circle class=\"mdc-circular-progress__determinate-circle\" cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"113.097\" stroke-width=\"4\"/>\n        </svg>\n    </div>\n    <div class=\"mdc-circular-progress__indeterminate-container\">\n        <div class=\"mdc-circular-progress__spinner-layer\">\n            <div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-left\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"4\"/>\n                </svg>\n            </div>\n            <div class=\"mdc-circular-progress__gap-patch\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"3.2\"/>\n                </svg>\n            </div>\n            <div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-right\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"4\"/>\n                </svg>\n            </div>\n        </div>\n    </div>\n</div>\n";

let MooCircularProgress = class MooCircularProgress {
    progressEl;
    size;
    attached() {
        const progress = new circularProgress.MDCCircularProgress(this.progressEl);
        progress.determinate = false;
        progress.open();
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Number)
], MooCircularProgress.prototype, "size", void 0);
MooCircularProgress = __decorate([
    runtimeHtml.customElement({
        name: 'moo-circular-progress',
        template: template$g,
        containerless: true
    })
], MooCircularProgress);

const mooDialog = '';

const template$f = "<div class=\"mdc-dialog\" ref=\"dialogEl\">\n    <div class=\"mdc-dialog__container\">\n        <div class=\"mdc-dialog__surface\"\n             role=\"alertdialog\"\n             aria-modal=\"true\"\n             aria-labelledby=\"my-dialog-title\"\n             aria-describedby=\"my-dialog-content\">\n            <h2 class=\"mdc-dialog__title\" id=\"my-dialog-title\" if.bind=\"title\">${title}</h2>\n            <div class=\"mdc-dialog__content\" id=\"my-dialog-content\">\n                <au-slot></au-slot>\n            </div>\n            <div class=\"mdc-dialog__actions\">\n                <moo-button type=\"button\" data-mdc-dialog-action=\"cancel\">\n                    Cancel\n                </moo-button>\n                <moo-button type=\"button\" data-mdc-dialog-action=\"ok\" class=\"ms-3\">\n                    Confirm\n                </moo-button>\n            </div>\n        </div>\n    </div>\n    <div class=\"mdc-dialog__scrim\"></div>\n</div>\n";

let MooDialog = class MooDialog {
    dialogEl;
    dialog;
    handler;
    title;
    attached() {
        this.dialog = new dialog.MDCDialog(this.dialogEl);
        this.dialog.listen('MDCDialog:closed', (e)=>{
            if (this.handler) {
                this.handler(e);
            }
        });
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", HTMLElement)
], MooDialog.prototype, "dialogEl", void 0);
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", dialog.MDCDialog)
], MooDialog.prototype, "dialog", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Function)
], MooDialog.prototype, "handler", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooDialog.prototype, "title", void 0);
MooDialog = __decorate([
    runtimeHtml.customElement({
        name: 'moo-dialog',
        template: template$f,
        containerless: true
    })
], MooDialog);

const mooDrawer = '';

const template$e = "<div if.bind=\"!open\">\n    <moo-fab click.trigger=\"() => open = true\" class=\"bottomRight\">\n        <moo-icon>chevron_right</moo-icon>\n    </moo-fab>\n</div>\n<aside class=\"mdc-drawer mdc-drawer--dismissible\" ref=\"drawerEl\">\n    <div class=\"close-icon\">\n        <moo-fab click.trigger=\"() => open = false\" class=\"topRight\">\n            <moo-icon>chevron_left</moo-icon>\n        </moo-fab>\n    </div>\n    <div class=\"mdc-drawer__content\">\n        <au-slot></au-slot>\n    </div>\n</aside>\n";

let MooDrawer = class MooDrawer {
    open;
    drawerEl;
    drawer;
    didAttach = false;
    attached() {
        if (!this.didAttach) {
            this.drawer = drawer.MDCDrawer.attachTo(this.drawerEl);
            this.drawer.open = this.open;
            this.didAttach = true;
        }
    }
    openChanged() {
        this.drawer.open = this.open;
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooDrawer.prototype, "open", void 0);
MooDrawer = __decorate([
    runtimeHtml.customElement({
        name: 'moo-drawer',
        template: template$e,
        containerless: true
    })
], MooDrawer);

const template$d = "<a if.bind=\"url\" href.bind=\"url\" ...$attrs>\n    <md-fab variant.bind=\"variant\" label.bind=\"label\">\n        <au-slot></au-slot>\n    </md-fab>\n</a>\n<md-fab else ...$attrs variant.bind=\"variant\" label.bind=\"label\">\n    <au-slot></au-slot>\n</md-fab>\n";

let MooFab = class MooFab {
    url;
    variant;
    label;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooFab.prototype, "url", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooFab.prototype, "variant", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooFab.prototype, "label", void 0);
MooFab = __decorate([
    runtimeHtml.customElement({
        name: 'moo-fab',
        template: template$d,
        containerless: true,
        capture: true
    })
], MooFab);

const mooFormField = '';

const template$c = "<div class=\"mdc-form-field\" ref=\"formFieldEl\">\n    <au-slot></au-slot>\n    <label>${label}</label>\n</div>\n";

let MooFormField = class MooFormField {
    label;
    options;
    class;
    disabled;
    formFieldEl;
    formField;
    attached() {
        this.formField = new formField.MDCFormField(this.formFieldEl);
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooFormField.prototype, "label", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooFormField.prototype, "options", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooFormField.prototype, "class", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooFormField.prototype, "disabled", void 0);
MooFormField = __decorate([
    runtimeHtml.customElement({
        name: 'moo-form-field',
        template: template$c,
        containerless: true
    })
], MooFormField);

const template$b = "<md-icon slot=\"icon\">\n    <au-slot></au-slot>\n</md-icon>\n";

let MooIcon = class MooIcon {
};
MooIcon = __decorate([
    runtimeHtml.customElement({
        name: 'moo-icon',
        template: template$b,
        containerless: true,
        capture: true
    })
], MooIcon);

const template$a = "<md-list>\n    <au-slot></au-slot>\n</md-list>\n";

let MooList = class MooList {
};
MooList = __decorate([
    runtimeHtml.customElement({
        name: 'moo-list',
        template: template$a,
        containerless: true
    })
], MooList);

const template$9 = "<a ...$attrs load=\"${route}\" if.bind=\"route\">\n    <md-list-item>\n        <au-slot></au-slot>\n    </md-list-item>\n</a>\n<md-list-item ...$attrs else>\n    <au-slot></au-slot>\n</md-list-item>\n";

let MooListItem = class MooListItem {
    route;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooListItem.prototype, "route", void 0);
MooListItem = __decorate([
    runtimeHtml.customElement({
        name: 'moo-list-item',
        template: template$9,
        containerless: true,
        capture: true
    })
], MooListItem);

const template$8 = "<md-menu id=\"usage-menu\" anchor.bind=\"anchor\" open.bind=\"open\">\n    <au-slot></au-slot>\n</md-menu>\n";

let MooMenu = class MooMenu {
    open = false;
    anchor;
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooMenu.prototype, "open", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooMenu.prototype, "anchor", void 0);
MooMenu = __decorate([
    runtimeHtml.customElement({
        name: 'moo-menu',
        template: template$8,
        containerless: true
    })
], MooMenu);

const template$7 = "<md-menu-item>\n    <div slot=\"headline\">\n        <au-slot></au-slot>\n    </div>\n</md-menu-item>\n";

let MooMenuItem = class MooMenuItem {
};
MooMenuItem = __decorate([
    runtimeHtml.customElement({
        name: 'moo-menu-item',
        template: template$7,
        containerless: true
    })
], MooMenuItem);

const mooRadio = '';

const template$6 = "<div class=\"mdc-radio\" ref=\"radioEl\">\n    <input class=\"mdc-radio__native-control\" type=\"radio\" name=\"radios\" checked.bind=\"checked\" disabled.bind=\"disabled\">\n    <div class=\"mdc-radio__background\">\n        <div class=\"mdc-radio__outer-circle\"></div>\n        <div class=\"mdc-radio__inner-circle\"></div>\n    </div>\n    <div class=\"mdc-radio__ripple\"></div>\n    <div class=\"mdc-radio__focus-ring\"></div>\n</div>\n";

let MooRadio = class MooRadio {
    label;
    options;
    model;
    value;
    class;
    disabled;
    checked = false;
    radioEl;
    radio;
    attached() {
        if (this.model == this.value) {
            this.checked = true;
        }
        console.log('this.model', this.model);
        console.log('this.value', this.value);
        this.radio = new radio.MDCRadio(this.radioEl);
        console.log(this.checked);
    }
    clickHandler() {
        console.log('clicked', this.radio.value);
    }
    handleRadioChecked() {
        console.log('radio checked', this.radio.checked);
    }
    handleRadioValue() {
        console.log('radio value', this.radio.value);
    }
    handleCheckChanged() {
        console.log('this.checked', this.checked);
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooRadio.prototype, "label", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooRadio.prototype, "options", void 0);
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooRadio.prototype, "model", void 0);
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooRadio.prototype, "value", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooRadio.prototype, "class", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooRadio.prototype, "disabled", void 0);
__decorate([
    runtimeHtml.watch('radio.checked'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], MooRadio.prototype, "handleRadioChecked", null);
__decorate([
    runtimeHtml.watch('radio'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], MooRadio.prototype, "handleRadioValue", null);
__decorate([
    runtimeHtml.watch('checked'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], MooRadio.prototype, "handleCheckChanged", null);
MooRadio = __decorate([
    runtimeHtml.customElement({
        name: 'moo-radio',
        template: template$6,
        containerless: true
    })
], MooRadio);

const template$5 = "<div if.bind=\"!options\">\n    <h4 class=\"text-danger\">SELECT NEEDS UPDATE</h4>\n</div>\n<md-outlined-select\n    ...$attrs\n    if.bind=\"selectType === 'outlined'\"\n    class.bind=\"class\"\n    required.bind=\"required\"\n    onchange.bind=\"(e) => handleChange(e)\"\n    label.bind=\"label\"\n    value.bind=\"value\"\n    ref=\"selectEl\"\n>\n    <md-select-option aria-label=\"blank\" if.bind=\"includeNull\" selected.bind=\"shouldBeSelected(null)\">\n        -- None --\n    </md-select-option>\n    <md-select-option repeat.for=\"option of options\" value.bind=\"option.value\" selected.bind=\"shouldBeSelected(option)\">\n        <div slot=\"headline\">${option.label}</div>\n    </md-select-option>\n</md-outlined-select>\n\n\n<md-filled-select\n    ...$attrs\n    else\n    class.bind=\"class\"\n    required.bind=\"required\"\n    onchange.bind=\"(e) => handleChange(e)\"\n    label.bind=\"label\"\n    value.bind=\"value\"\n    ref=\"selectEl\"\n>\n    <md-select-option aria-label=\"blank\" if.bind=\"includeNull\" selected.bind=\"shouldBeSelected(null)\">\n        -- None --\n    </md-select-option>\n    <md-select-option repeat.for=\"option of options\" value.bind=\"option.value\" selected.bind=\"shouldBeSelected(option)\">\n        <div slot=\"headline\">${option.label}</div>\n    </md-select-option>\n</md-filled-select>\n";

let MooSelect = class MooSelect {
    label;
    options;
    value;
    class;
    required;
    readonly;
    selectType = 'outlined';
    includeNull = false;
    handleChange(e) {
        this.value = e.target.value;
    }
    shouldBeSelected(option) {
        if (this.includeNull && !this.value) {
            return true;
        }
        if (!option) {
            return false;
        }
        return option.value == this.value;
    }
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooSelect.prototype, "label", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Array)
], MooSelect.prototype, "options", void 0);
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooSelect.prototype, "value", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooSelect.prototype, "class", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooSelect.prototype, "required", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Boolean)
], MooSelect.prototype, "readonly", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooSelect.prototype, "selectType", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Object)
], MooSelect.prototype, "includeNull", void 0);
MooSelect = __decorate([
    runtimeHtml.customElement({
        name: 'moo-select',
        template: template$5,
        containerless: true
    })
], MooSelect);

const template$4 = "<label class=\"pt-1 pe-1\" for=\"switch\">${label}</label>\n<md-switch ref=\"switch\" selected.bind=\"value\" id=\"switch\"></md-switch>\n";

let MooSwitch = class MooSwitch {
    value;
    class;
    change;
    label;
    switch;
    attached() {
        this.switch.selected = this.value;
        this.switch.addEventListener('change', ()=>this.handleChange());
    }
    handleChange() {
        this.value = !this.value;
        this.change();
    }
};
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Boolean)
], MooSwitch.prototype, "value", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooSwitch.prototype, "class", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", Function)
], MooSwitch.prototype, "change", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooSwitch.prototype, "label", void 0);
MooSwitch = __decorate([
    runtimeHtml.customElement({
        name: 'moo-switch',
        template: template$4,
        containerless: true
    })
], MooSwitch);

const template$3 = "<md-primary-tab ...$attrs if.bind=\"variant === 'primary'\">\n    <au-slot></au-slot>\n</md-primary-tab>\n\n<md-secondary-tab ...$attrs if.bind=\"variant === 'secondary'\">\n    <au-slot></au-slot>\n</md-secondary-tab>\n";

let MooTab = class MooTab {
    variant = 'primary';
};
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooTab.prototype, "variant", void 0);
MooTab = __decorate([
    runtimeHtml.customElement({
        name: 'moo-tab',
        template: template$3,
        containerless: true,
        capture: true
    })
], MooTab);

const template$2 = "<md-tabs ...$attrs>\n    <au-slot></au-slot>\n</md-tabs>\n";

let MooTabs = class MooTabs {
};
MooTabs = __decorate([
    runtimeHtml.customElement({
        name: 'moo-tabs',
        template: template$2,
        containerless: true,
        capture: true
    })
], MooTabs);

const template$1 = "<md-filled-text-field\n    ...$attrs\n    value.bind=\"value\"\n    if.bind=\"variant === 'filled'\"\n    ref=\"mdElement\"\n></md-filled-text-field>\n\n<md-outlined-text-field\n    ...$attrs\n    value.bind=\"value\"\n    if.bind=\"variant === 'outlined'\"\n    ref=\"mdElement\"\n></md-outlined-text-field>\n";

let MooTextField = class MooTextField {
    value;
    variant = 'outlined';
    mdElement;
    attached() {
        this.mdElement.addEventListener('keyup', ()=>this.value = this.mdElement.value);
    }
};
__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooTextField.prototype, "value", void 0);
__decorate([
    runtimeHtml.bindable,
    __metadata("design:type", String)
], MooTextField.prototype, "variant", void 0);
MooTextField = __decorate([
    runtimeHtml.customElement({
        name: 'moo-text-field-test',
        template: template$1,
        containerless: true,
        capture: true
    })
], MooTextField);

const mooTopbar = '';

const template = "<header class=\"mdc-top-app-bar mdc-top-app-bar--fixed\" ref=\"header\">\n    <div class=\"mdc-top-app-bar__row\">\n        <au-slot></au-slot>\n    </div>\n</header>\n<div class=\"mdc-top-app-bar--fixed-adjust\"></div>\n";

let MooTopbar = class MooTopbar {
    header;
    attached() {
        new topAppBar.MDCTopAppBar(this.header);
    }
};
MooTopbar = __decorate([
    runtimeHtml.customElement({
        name: 'moo-topbar',
        template,
        containerless: true
    })
], MooTopbar);

const elements = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get MooAccordion () { return MooAccordion; },
    get MooBanner () { return MooBanner; },
    get MooButton () { return MooButton; },
    get MooCard () { return MooCard; },
    get MooCardContent () { return MooCardContent; },
    get MooCardFooter () { return MooCardFooter; },
    get MooCardHeader () { return MooCardHeader; },
    get MooCheckbox () { return MooCheckbox; },
    get MooChip () { return MooChip; },
    get MooChipSet () { return MooChipSet; },
    get MooCircularProgress () { return MooCircularProgress; },
    get MooDialog () { return MooDialog; },
    get MooDrawer () { return MooDrawer; },
    get MooFab () { return MooFab; },
    get MooFormField () { return MooFormField; },
    get MooIcon () { return MooIcon; },
    get MooList () { return MooList; },
    get MooListItem () { return MooListItem; },
    get MooMenu () { return MooMenu; },
    get MooMenuItem () { return MooMenuItem; },
    get MooRadio () { return MooRadio; },
    get MooSelect () { return MooSelect; },
    get MooSwitch () { return MooSwitch; },
    get MooTab () { return MooTab; },
    get MooTabs () { return MooTabs; },
    get MooTextField () { return MooTextField; },
    get MooTopbar () { return MooTopbar; }
}, Symbol.toStringTag, { value: 'Module' }));

let TakeValueConverter = class TakeValueConverter {
    toView(value, amount) {
        return value.slice(0, amount);
    }
};
TakeValueConverter = __decorate([
    runtimeHtml.valueConverter('take')
], TakeValueConverter);

let SkipValueConverter = class SkipValueConverter {
    toView(value, amount) {
        return value.slice(amount);
    }
};
SkipValueConverter = __decorate([
    runtimeHtml.valueConverter('skip')
], SkipValueConverter);

const valueConverters = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get SkipValueConverter () { return SkipValueConverter; },
    get TakeValueConverter () { return TakeValueConverter; }
}, Symbol.toStringTag, { value: 'Module' }));

const main = '';

class BetsyWebComponentsPlugin {
    #configuration;
    static configure(...args) {
        const instance = new BetsyWebComponentsPlugin();
        if (typeof args[0] === 'function') {
            instance.#configuration = {
                iconMap: new Map()
            };
            args[0](instance.#configuration);
        } else {
            instance.#configuration = args[0];
        }
        if (!instance.#configuration.formatDateTime) {
            instance.#configuration.formatDateTime = (date)=>new Intl.DateTimeFormat('default', {
                    dateStyle: 'full'
                }).format(typeof date === 'string' ? new Date(date) : date);
        }
        if (!instance.#configuration.formatDate) {
            instance.#configuration.formatDate = (date)=>new Intl.DateTimeFormat('default', {
                    month: '2-digit',
                    day: '2-digit',
                    year: 'numeric'
                }).format(typeof date === 'string' ? new Date(date) : date);
        }
        if (!instance.#configuration.formatNumber) {
            instance.#configuration.formatNumber = (number)=>new Intl.NumberFormat('default', {
                    maximumFractionDigits: 2
                }).format(number == null ? 0 : Number(number));
        }
        if (!instance.#configuration.formatCurrency) {
            instance.#configuration.formatCurrency = (number)=>new Intl.NumberFormat('default', {
                    style: 'currency',
                    currency: 'usd'
                }).format(number == null ? 0 : Number(number));
        }
        if (!instance.#configuration.formatPercent) {
            instance.#configuration.formatPercent = (number)=>new Intl.NumberFormat('default', {
                    style: 'percent'
                }).format(number == null ? 0 : Number(number));
        }
        return instance;
    }
    register(container) {
        container.register(attributes);
        container.register(elements);
        container.register(valueConverters);
        container.register(kernel.Registration.instance(IBetsyWebComponentsConfiguration, this.#configuration));
        container.register(validationHtml.ValidationHtmlConfiguration.customize((options)=>{
            options.DefaultTrigger = validationHtml.ValidationTrigger.changeOrFocusout;
        }));
        // container = container.register(AppTask.beforeCreate(IContainer, async c => {
        //     // console
        //     console.log(this.#configuration)
        //     c.register(elements);
        //     c.register(attributes);
        // }));
        return container;
    }
}

exports.BetsyWebComponentsPlugin = BetsyWebComponentsPlugin;
exports.IBetsyWebComponentsConfiguration = IBetsyWebComponentsConfiguration;
exports.attributes = attributes;
exports.elements = elements;
exports.valueConverters = valueConverters;
//# sourceMappingURL=index.js.map
